==> mysql-query-builder-js-0.0.3.tgz: package/index.js <==
/*
The MIT License (MIT)

Copyright (c) 2015 Jayr Alencar

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/
'use strict';
function Builder(){
	this.mysql = require('mysql');
	this.config = {};
	this.connection = null;
	this._sql = '';
	this._table = null;
	this._fields = [];
	this._clausales = [];


	this.connectionTest = function(){
		if(!this.connection){
			throw "Not connected in a database";
		}
	}

	this.tableTest = function(){
		if(!this._table){
			throw "Please, inform a table";
		}
	}

	this.getWhere = function(){
		if(this._clausales.length>0){
			var str = " WHERE ";
			for(var i in this._clausales){
				var cl = this._clausales[i];
				if(i == 0){
					str += cl.where;
				}else{
					if(cl.type == 1){
						str+=" AND "+cl.where;
					}else{
						str+=" OR "+cl.where;
					}
				}
			}
			return str;
		}else{
			return '';
		}
	}
}

/**
* Database connection
*
* @param {Object} config - host, database, user, pass, port
* @return {Object} this
*/
Builder.prototype.connect = function(config) {
	this.config = config;
	this.connection = this.mysql.createConnection(this.config);
	this.connection.connect();
	return this;
};

/**
* Choose table
*
* @param {String} table - table name
* @return {Object} this
*/
Builder.prototype.table = function(table){
	this.connectionTest();
	this._table = table;
	this._clausales = [];
	return this;
}

/**
* Inform fields
*
* @param {String|Object} fields
* @return {Object} this
*/
Builder.prototype.select = function(fields){
	this.tableTest();
	this._fields = [];
	if(arguments.length > 1){
		for(var i = 0 ; i < arguments.length ; i++){
			this._fields.push(arguments[i]);
		}
	}else{
		if(typeof(fields) == 'string'){
			this._fields = fields.spit(',');
		}else{
			this._fields = fields;
		}
	}
	return this;
}

/**
* Add field
*
* @param {String} field
* @return {Object} this
*/
Builder.prototype.addSelect = function(field){
	this.tableTest();
	this._fields.push(field);
	return this;
}

/**
* Where
* @param {String|Array} params
* @return {Object} this
*/
Builder.prototype.where = function(param){
	this.tableTest();
	if(arguments.length > 1){
		if(arguments.length > 2){
			this._clausales.push({
				type:1,
				where: arguments[0] + " " + arguments[1] + " '" + arguments[2] + "'"
			});
		}else{
			this._clausales.push({
				type:1,
				where: arguments[0] + " = '" + arguments[1] + "'"
			});
		}
	}else{
		for(var i = 0 ; i < param.length; i++){
			if(param[i].length > 2){
				this._clausales.push({
					type:1,
					where: param[i][0] + " " + param[i][1] + " '" + param[i][2] + "'"
				});
			}else{
				this._clausales.push({
					type:1,
					where: param[i][0] + " = '" + param[i][1] + "'"
				});
			}
		}
	}
	return this;
}

/**
* Where Or
* @param {String|Array} params
* @return {Object} this
*/
Builder.prototype.whereOr = function(param){
	this.tableTest();
	if(arguments.length > 1){
		if(arguments.length > 2){
			this._clausales.push({
				type:2,
				where: arguments[0] + " " + arguments[1] + " '" + arguments[2] + "'"
			});
		}else{
			this._clausales.push({
				type:2,
				where: arguments[0] + " = '" + arguments[1] + "'"
			});
		}
	}else{
		for(var i = 0 ; i < param.length; i++){
			if(param[i].length > 2){
				this._clausales.push({
					type:2,
					where: param[i][0] + " " + param[i][1] + " '" + param[i][2] + "'"
				});
			}else{
				this._clausales.push({
					type:2,
					where: param[i][0] + " = '" + param[i][1] + "'"
				});
			}
		}
	}
	return this;
}

/**
* Get query result
*
* @ param {Function} callback
* @return {Object} this
*/
Builder.prototype.get = function(callback){
	this.sql = "SELECT "+this._fields.join(',')+" FROM "+this._table+this.getWhere();

	this.connection.query(this.sql, function(err, rows, fields){
		callback(err, rows, fields, this.sql);
	});
	return this;
}


module.exports = new Builder();

==> mysql-query-builder-js-0.0.14.tgz: package/index.js <==
/*
The MIT License (MIT)

Copyright (c) 2015 Jayr Alencar

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/
'use strict';
function Builder(){
	this.mysql = require('mysql');
	this.config = {};
	this.connection = null;
	this._sql = '';
	this._table = null;
	this._fields = [];

	this.connectionTest = function(){
		if(!this.connection){
			throw "Not connected in a database";
		}
	}

	this.tableTest = function(){
		if(!this._table){
			throw "Please, inform a table";
		}
	}
}

Builder.prototype = require('./src/where.js');

/**
* Database connection
*
* @param {Object} config - host, database, user, pass, port
* @return {Object} this
*/
Builder.prototype.connect = function(config) {
	this.config = config;
	this.connection = this.mysql.createConnection(this.config);
	this.connection.connect();
	return this;
};

/**
* Choose table
*
* @param {String} table - table name
* @return {Object} this
*/
Builder.prototype.table = function(table){
	this.connectionTest();
	this._table = table;
	this._clausales = [];
	this._joins = []
	return this;
}

/**
* Inform fields
*
* @param {String|Object} fields
* @return {Object} this
*/
Builder.prototype.select = function(fields){
	this.tableTest();
	this._fields = [];
	if(arguments.length > 1){
		for(var i = 0 ; i < arguments.length ; i++){
			this._fields.push(arguments[i]);
		}
	}else{
		if(typeof(fields) == 'string'){
			this._fields = fields.spit(',');
		}else{
			this._fields = fields;
		}
	}
	return this;
}

/**
* Add field
*
* @param {String} field
* @return {Object} this
*/
Builder.prototype.addSelect = function(field){
	this.tableTest();
	this._fields.push(field);
	return this;
}

/**
* Get query result
*
* @ param {Function} callback
* @return {Object} this
*/
Builder.prototype.get = function(callback){
	this.connectionTest();
	this.tableTest();
	this._fields = (this._fields.length>0)?this._fields:['*'];
	this.sql = "SELECT "+this._fields.join(',')+" FROM "+this._table+this.getJoin()+" "+this.getWhere();

	this.connection.query(this.sql, function(err, rows, fields){
		callback(err, rows, fields, this.sql);
	});
	return this;
}

/**
* query
* @param {String} sql, {Function} callback
* @return {Object} this
*/
Builder.prototype.query = function(sql,options, callback){
	if(!callback){
		callback = options;
		options = [];
	}

	this.connection.query(sql,options,callback);
	return this;
}

module.exports = new Builder();
